#!/bin/sh

_SAMPLE_DIR_=`dirname "$0"`
_YH_="$_SAMPLE_DIR_/../.."

# Specify path to proper version of profiler agent library, depending on the OS
if [ `uname` = 'Linux' ] ; then
  if [ "`uname -a | grep x86_64`" ] ; then
    # Assume Linux AMD 64 has 64-bit Java
    export LD_LIBRARY_PATH="$_YH_/bin/linux-x86-64:$LD_LIBRARY_PATH"
  else
    # 32-bit Java
    export LD_LIBRARY_PATH="$_YH_/bin/linux-x86-32:$LD_LIBRARY_PATH"
  fi
elif [ `uname` = 'Darwin' ] ; then
  # Mac OS X
  export DYLD_LIBRARY_PATH="$_YH_/bin/mac:$DYLD_LIBRARY_PATH"
elif [ `uname` = 'SunOS' ] ; then
  # Solaris, unlike Linux, probes entire LD_LIBRARY_PATH instead of stopping after first improper shared library
  LD_LIBRARY_PATH="$_YH_/bin/solaris-sparc-32:$_YH_/bin/solaris-sparc-64:$_YH_/bin/solaris-x86-32:$_YH_/bin/solaris-x86-64:$LD_LIBRARY_PATH"
  export LD_LIBRARY_PATH
elif [ `uname` = 'FreeBSD' ] ; then
  if [ "`uname -a | grep amd64`" ] ; then
    export LD_LIBRARY_PATH="$_YH_/bin/freebsd-x86-64:$LD_LIBRARY_PATH"
  elif [ "`uname -a | grep i386`" ] ; then
    export LD_LIBRARY_PATH="$_YH_/bin/freebsd-x86-32:$LD_LIBRARY_PATH"
  else
    echo "Unsupported processor architecture"
    exit
  fi
else
  echo "Unsupported platform: `uname`"
  exit
fi

if [ `uname` = 'Darwin' ] ; then
  # Make sure on Mac OS X Java 5 is used
  JAVA_EXE=/System/Library/Frameworks/JavaVM.framework/Versions/1.5/Home/bin/java
  if [ ! -r "$JAVA_EXE" ] ; then
    echo "Java 5 is not found in its standard location ($JAVA_EXE)"
    exit
  fi
else
  JAVA_EXE=java

  JAVA5=`java -version 2>&1 | grep 1.5`
  JAVA6=`java -version 2>&1 | grep 1.6`
  JAVA7=`java -version 2>&1 | grep 1.7`
  if [ -z "$JAVA5" ] && [ -z "$JAVA6" ] && [ -z "$JAVA7" ] ; then
    echo "To run this example ensure you have Java 5 or newer in your current PATH."
    exit
  fi
fi

"$JAVA_EXE" -agentlib:yjpagent -classpath "$_SAMPLE_DIR_/classes" com.yourkit.examples.MyMainFrame
